/*******************************************************************************
 * Licensed Materials - Property of IBM
 * (c) Copyright IBM Corporation 2007-2008. All Rights Reserved.
 * 
 * Note to U.S. Government Users Restricted Rights:
 * Use, duplication or disclosure restricted by GSA ADP Schedule
 * Contract with IBM Corp.
 *******************************************************************************/
(function() {

dojo.provide("com.ibm.rational.report.web.core.app.internal.common.NavSection");

dojo.require("dijit._Widget");
dojo.require("dijit._Templated");
dojo.require("net.jazz.ajax.core.internal.util");

var TWISTIE_OPEN_SRC	= dojo.moduleUrl("net.jazz.ajax", "ui/internal/images/twistie-open.gif");
var TWISTIE_CLOSED_SRC	= dojo.moduleUrl("net.jazz.ajax", "ui/internal/images/twistie-closed.gif");
var TWISTIE_3QUARTER_SRC = dojo.moduleUrl("net.jazz.ajax", "ui/internal/images/twistie-3quarter.gif");
var DROPDOWN_HOVER		= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/icons/dd-arrow-hov.gif");
var DROPDOWN			= dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/icons/dd-arrow.gif");

function isWidget(o) {
	return o.buildRendering && o.postCreate;
}

function show() {
	dojo.forEach(arguments, function(x) {
		if (x) {
			dojo.removeClass(x, "net-jazz-ajax-hidden");
		}
	});
}

function hide() {
	dojo.forEach(arguments, function(x) {
		if (x) {
			dojo.addClass(x, "net-jazz-ajax-hidden");
		}
	});
}

/*
 * Displays the Left Navigator Drawer.
 */
dojo.declare(
	"com.ibm.rational.report.web.core.app.internal.common.NavSection",
	[dijit._Widget, dijit._Templated], {
		
	templatePath: dojo.moduleUrl("com.ibm.rational.report.web.core", "app/internal/common/templates/NavSection.html"),
		
	postCreate: function() {
		// add a reference to this widget into the links that can toggle the
		// display state of the widget (see LeftNavigationLayout#_routeClick,
		// above).
		var self = this;
		dojo.forEach(
			[this._togglerLink, this._showMore, this._showLess],
			function(x) {
				x["__jazzNavSection"] = self;
			});
		
		if(this.showSeparator){
			dojo.addClass(this.domNode, "net-jazz-ajax-SideNavigationLayout-navSectionSeparator");
		}
		
		// we won't display the toggler if there's no title
		if (this.title) {
			this._togglerLink.appendChild(document.createTextNode(this.title));
		} else {
			this._togglerLink.className = "net-jazz-ajax-hidden";
		}
		
		if(isWidget(this.o)) {
			// if this is a widget, check to see if it supports a 'partially
			// open' display state
			this.contentWidget = this.o;
			var domNode = this.o.domNode;
			this._has3Qtr = dojo.isFunction(this.o.onShowPartial) &&
				dojo.isFunction(this.o.onMaximize);
		} else {
			// backwards compatibility with old API
			domNode = this.o;
		}
		
		this._contentContainer.appendChild(domNode);
		var initialState = this._has3Qtr ? "showPartial" : "maximize";
		this._runAction(initialState);
	},
	
	_runAction: function(action) {
		if (action === "minimize") {
			// in the minimize case, we hide everything
			var nextAction = this._has3Qtr ? "/showPartial" : "/maximize";
			this._setToggler(TWISTIE_CLOSED_SRC, nextAction);
			if(this._has3Qtr && dojo.isFunction(this.contentWidget.onMinimize)) {
				this.contentWidget.onMinimize();
			}
			hide(this._contentContainer, this._showMore, this._showLess);
		} else if (action === "maximize") {
			this._setToggler(TWISTIE_OPEN_SRC, "/minimize");
			hide(this._showMore);
			show(this._contentContainer);
			if(this._has3Qtr) {
				show(this._showLess);
				this.contentWidget.onMaximize();
			} else {
				hide(this._showLess);
			}
		} else {
			// if we're in the partial view case, we know we support maximize
			this._setToggler(TWISTIE_3QUARTER_SRC, "/maximize");
			hide(this._showLess);
			show(this._contentContainer, this._showMore);
			this.contentWidget.onShowPartial();
		}
		
	},
	
	_setToggler: function(currentStateImg, actionUri) {
		this._toggler.src = currentStateImg;
		this._togglerLink.href = actionUri;
	}
	
});

})();